@@ -1,9 +1,7 @@
 use crate::fs::{open, FollowSymlinks, OpenOptions};
-use std::{
-    fs, io,
-    os::windows::fs::OpenOptionsExt,
-    path::{Path, PathBuf},
-};
+use std::os::windows::fs::OpenOptionsExt;
+use std::path::{Path, PathBuf};
+use std::{fs, io};
 use winapi::um::winbase::{FILE_FLAG_BACKUP_SEMANTICS, FILE_FLAG_OPEN_REPARSE_POINT};
 
 /// *Unsandboxed* function similar to `read_link`, but which does not perform
